Crate holochain_conductor_services

Crate holochain_conductor_services 

Conductor Services

The conductor expects to be able to interface with some arbitrarily defined “services” whose implementation details we don’t know or care about. We want well-defined interfaces for these services such that a third party could write their own.

Modules

__mock_MockAppStoreService
__mock_MockAppStoreService_AppStoreService
__mock_MockDpkiState
__mock_MockDpkiState_DpkiState
app_binding
authority_spec
authorized_spec_change
change_rule
derivation_paths
hdk
The Holochain Development Kit (HDK) provides high and low level functions for writing Holochain applications.
key_anchor
key_meta
key_registration
keyset_root

Structs

AppBinding
AppBindingInput
AppStoreBuiltin
The built-in implementation of the app store service, which runs a DNA
AuthoritySpec
AuthoritySpecInput
AuthorizedSpecChange
ChangeRule
ConductorServiceCells
Initialized for ConductorService: just the CellIds that are used for each service
ConductorServices
The set of all Conductor Services available to the conductor
CreateKeyInput
DeepkeyInstallation
Data needed to initialize the Deepkey service, if installed. FIXME: this assumes that DPKI will be implemented by a cell, which may not be the case in general. To generalize is currently out of scope.
DeepkeyState
DerivationDetails
DerivationDetailsInput
DpkiService
KeyAnchor
A deterministic entry that contains only the cord 32 bytes of a key
KeyGeneration
KeyMeta
KeyRevocation
KeyRevocationInput
KeysetRoot
MockAppStoreService
Interface for the AppStore service
MockDpkiState
RevokeKeyInput
UpdateChangeRuleInput
UpdateKeyInput

Enums

AppHash
This doesn’t exist yet. We need to define it.
AppStoreServiceError
The errors which can be produced by the AppStoreService
DpkiServiceError
The errors which can be produced by DPKI
KeyRegistration
Registration information used to validate operations on a KeyAnchor
KeyState

Constants

DPKI_APP_ID
This magic string, when used as the installed app id, denotes that the app is not actually an app, but the DPKI service! This is now a reserved app id, and is used to distinguish the DPKI service from other apps.
KEYSET_ROOT_INDEX

Traits

AppStoreService
Interface for the AppStore service
CellRunner
DpkiState

Functions

mock_app_store
Create a minimal usable mock of the app store

Type Aliases

AppStoreServiceResult
Alias
Authorization
DpkiImpl
DpkiServiceResult
Alias
KeyBytes
MetaData