Conductor Services
The conductor expects to be able to interface with some arbitrarily defined “services” whose implementation details we don’t know or care about. We want well-defined interfaces for these services such that a third party could write their own.
Modules
- __
mock_ Mock AppStore Service - __
mock_ Mock AppStore Service_ AppStore Service - __
mock_ Mock Dpki State - __
mock_ Mock Dpki State_ Dpki State - app_
binding - authority_
spec - authorized_
spec_ change - change_
rule - derivation_
paths - hdk
- The Holochain Development Kit (HDK) provides high and low level functions for writing Holochain applications.
- key_
anchor - key_
meta - key_
registration - keyset_
root
Structs
- AppBinding
- AppBinding
Input - AppStore
Builtin - The built-in implementation of the app store service, which runs a DNA
- Authority
Spec - Authority
Spec Input - Authorized
Spec Change - Change
Rule - Conductor
Service Cells - Initialized for ConductorService: just the CellIds that are used for each service
- Conductor
Services - The set of all Conductor Services available to the conductor
- Create
KeyInput - Deepkey
Installation - Data needed to initialize the Deepkey service, if installed. FIXME: this assumes that DPKI will be implemented by a cell, which may not be the case in general. To generalize is currently out of scope.
- Deepkey
State - Derivation
Details - Derivation
Details Input - Dpki
Service - KeyAnchor
- A deterministic entry that contains only the cord 32 bytes of a key
- KeyGeneration
- KeyMeta
- KeyRevocation
- KeyRevocation
Input - Keyset
Root - Mock
AppStore Service - Interface for the AppStore service
- Mock
Dpki State - Revoke
KeyInput - Update
Change Rule Input - Update
KeyInput
Enums
- AppHash
- This doesn’t exist yet. We need to define it.
- AppStore
Service Error - The errors which can be produced by the AppStoreService
- Dpki
Service Error - The errors which can be produced by DPKI
- KeyRegistration
- Registration information used to validate operations on a
KeyAnchor - KeyState
Constants
- DPKI_
APP_ ID - This magic string, when used as the installed app id, denotes that the app is not actually an app, but the DPKI service! This is now a reserved app id, and is used to distinguish the DPKI service from other apps.
- KEYSET_
ROOT_ INDEX
Traits
- AppStore
Service - Interface for the AppStore service
- Cell
Runner - Dpki
State
Functions
- mock_
app_ store - Create a minimal usable mock of the app store